# SciDataTool
## Presentation
SciDataTool's objective is to provide a **user-friendly, unified, flexible scientific data tool** based on open-source python package.

It is meant to be used by researchers, R&D engineers and teachers in any scientific area. This package allows to efficiently store data fields in the time/space or in the frequency domain, to easily perform **Fourier Transforms**, to extract **slices**, to **convert units**, to **compare** several fields, etc. It also includes simplified **plot** commands.

## Origin and status of the project
EOMYS has started an open and non-commercial project named Pyleecan (Python Library for Electrical Engineering Computational Analysis). In this context, a scientific data tool has been implemented with the intent to be as generic as possible. The resulting module could be used in any scientific area, and benefit from exterior developments, hence the idea to create the separated open-source project.

## Documentation
Tutorials are available in the [Tutorials folder](https://github.com/Eomys/SciDataTool/tree/master/Tutorials).

## Contact
You can contact us on Github by opening an issue (to request a feature, ask a question or report a bug).
